@@ -1,15 +1,10 @@
-/**
- * Copyright (c) 2014-present, Facebook, Inc.
- *
- * This source code is licensed under the MIT license found in the
- * LICENSE file in the root directory of this source tree.
- */
-
 /**
  * Contributes additional methods to a constructor
  */
 export default function mixin(ctor, methods) {
-  var keyCopier = key => { ctor.prototype[key] = methods[key]; };
+  const keyCopier = key => {
+    ctor.prototype[key] = methods[key];
+  };
   Object.keys(methods).forEach(keyCopier);
   Object.getOwnPropertySymbols &&
     Object.getOwnPropertySymbols(methods).forEach(keyCopier);
